@@ -89,6 +89,8 @@ GB2312
 i18n:Chinese Simplified
 EUC-KR
 i18n:Korean
+cp 949
+i18n:Korean
 sjis
 i18n:Japanese
 jis7
@@ -184,6 +186,7 @@ static const char language_for_encoding_string[] =
     "GB2312\0"
     "EUC-KR\0"
     I18N_NOOP2("@item Text character set", "Korean")"\0"
+    "cp 949\0"
     "sjis\0"
     I18N_NOOP2("@item Text character set", "Japanese")"\0"
     "jis7\0"
@@ -223,12 +226,12 @@ static const int language_for_encoding_indices[] = {
      193,  117,  201,  208,  217,  208,  228,  208,
      236,  208,  243,  208,  250,  255,  275,  255,
      286,  294,  313,  294,  317,  294,  324,  331,
-     338,  343,  352,  343,  357,  343,  364,  375,
-     381,  375,  389,  400,  407,  400,  415,  426,
-     433,  426,  446,  426,  454,  185,  465,  472,
-     477,  472,  489,  495,  503,  495,  510,  495,
-     515,  495,  520,  495,  536,  545,  560,  573,
-     579,  573,  586,  573,   -1
+     338,  331,  345,  350,  359,  350,  364,  350,
+     371,  382,  388,  382,  396,  407,  414,  407,
+     422,  433,  440,  433,  453,  433,  461,  185,
+     472,  479,  484,  479,  496,  502,  510,  502,
+     517,  502,  522,  502,  527,  502,  543,  552,
+     567,  580,  586,  580,  593,  580,   -1
 };
 
 /*
@@ -265,6 +268,8 @@ big5-0
 big5
 euc-kr
 euckr
+cp949
+cp 949
 euc-jp
 eucjp
 jisx0201.1976-0
@@ -355,6 +360,8 @@ static const char builtin_string[] =
     "big5\0"
     "euc-kr\0"
     "euckr\0"
+    "cp949\0"
+    "cp 949\0"
     "euc-jp\0"
     "eucjp\0"
     "jisx0201.1976-0\0"
@@ -395,14 +402,14 @@ static const int builtin_indices[] = {
        0,   11,   18,   11,   30,   39,   50,   39,
       58,   39,   64,   82,   88,   93,  109,   93,
      120,  135,  143,  135,  158,  164,  168,  164,
-     175,  164,  189,  196,  201,  208,  214,  221,
-     227,  221,  243,  221,  259,  221,  275,  221,
-     291,  221,  307,  221,  323,  221,  339,  349,
-     354,  349,  349,  349,  364,  376,  381,  392,
-     399,  410,  417,  392,  429,  410,  441,  450,
-     462,  474,  486,  498,  505,  498,  516,  498,
-     523,  208,  538,  208,  553,  450,  563,  450,
-     573,  450,  577,  364,   -1
+     175,  164,  189,  196,  201,  208,  214,  220,
+     227,  234,  240,  234,  256,  234,  272,  234,
+     288,  234,  304,  234,  320,  234,  336,  234,
+     352,  362,  367,  362,  362,  362,  377,  389,
+     394,  405,  412,  423,  430,  405,  442,  423,
+     454,  463,  475,  487,  499,  511,  518,  511,
+     529,  511,  536,  208,  551,  208,  566,  463,
+     576,  463,  586,  463,  590,  377,   -1
 };
 
 /*
