@@ -26,14 +26,20 @@ class KLocaleTest : public QObject
 	Q_OBJECT
 private Q_SLOTS:
 	void initTestCase();
-	void formatNumbers();
+    void languages();
+    void formatNumbers();
 	void formatNumberStrings();
 	void readNumber();
+    void formatMoney();
+    void readMoney();
 	void formatDate();
 	void readDate();
 	void formatTime();
 	void formatDateTime();
 	void readTime();
+    void testDayPeriods();
+    void testCalendarSystemType();
+    void testCountryDivision();
 	void prettyFormatDuration();
 	void formatByteSize();
 	void bug95511();
