@@ -954,7 +954,38 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     QCOMPARE(secondDirLister.rootItem().url().toLocalFile(), newPath);
 
     disconnect(&secondDirLister, 0, this, 0);
-    QDir().remove(newPath);
+    QDir().rmdir(newPath);
+}
+
+void KDirListerTest::slotOpenUrlOnRename(const KUrl & newUrl)
+{
+  QVERIFY(m_dirLister.openUrl(newUrl));
+}
+
+//This tests for a crash if you connect redirects to openUrl, due
+//to internal data being inconsistently exposed.
+//Matches usage in gwenview.
+void KDirListerTest::testRenameCurrentDirOpenUrl()
+{
+    m_items.clear();
+    const QString path = m_tempDir.name() + "newsubdir-1";
+    QVERIFY(QDir().mkdir(path));
+    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+
+    m_dirLister.openUrl(KUrl(path));
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+
+    const QString newPath = m_tempDir.name() + "newsubdir-2";
+    QVERIFY(QDir().rename(path, newPath));
+
+    //Connect the redirection to openURL, so that on a rename the new location is opened.
+    //This matches usage in gwenview, and crashes without a fix
+    connect(&m_dirLister, SIGNAL(redirection(KUrl)), this, SLOT(slotOpenUrlOnRename(KUrl)));
+    org::kde::KDirNotify::emitFileRenamed(KUrl(path).url(), KUrl(newPath).url());
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(redirection(KUrl,KUrl)), 1000));
+    disconnect(&m_dirLister, 0, this, 0);
+    QDir().rmdir(newPath);
 }
 
 void KDirListerTest::testRedirection()
@@ -994,7 +1025,38 @@ void KDirListerTest::testRedirection()
     m_dirLister.stop(url);
     QVERIFY(!m_dirLister.isFinished());
     disconnect(&m_dirLister, 0, this, 0);
+}
 
+void KDirListerTest::testListEmptyDirFromCache() // #278431
+{
+    m_items.clear();
+
+    KTempDir newDir;
+    const QString path = newDir.name();
+
+    // List and watch an empty dir
+    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    m_dirLister.openUrl(QUrl::fromLocalFile(path));
+    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
+    QVERIFY(m_dirLister.isFinished());
+    QVERIFY(m_items.isEmpty());
+
+    // List it with two more dirlisters (one will create a cached items job, the second should also benefit from it)
+    MyDirLister secondDirLister;
+    connect(&secondDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    secondDirLister.openUrl(KUrl(path), KDirLister::NoFlags);
+    MyDirLister thirdDirLister;
+    connect(&thirdDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
+    thirdDirLister.openUrl(KUrl(path), KDirLister::NoFlags);
+
+    // The point of this test is that (with DEBUG_CACHE enabled) it used to assert here
+    // with "HUH? Lister KDirLister(0x7ffd1f044260) is supposed to be listing, but has no job!"
+    // due to the if (!itemU->lstItems.isEmpty()) check which is now removed.
+
+    QVERIFY(!secondDirLister.isFinished()); // we didn't go to the event loop yet
+    QVERIFY(QTest::kWaitForSignal(&secondDirLister, SIGNAL(completed()), 1000));
+    if (!thirdDirLister.isFinished())
+        QVERIFY(QTest::kWaitForSignal(&thirdDirLister, SIGNAL(completed()), 1000));
 }
 
 void KDirListerTest::testWatchingAfterCopyJob() // #331582
@@ -1113,7 +1175,7 @@ void KDirListerTest::testDirPermissionChange()
     QCOMPARE(list.count(), 1);
     QCOMPARE(mylister.rootItem().url().toLocalFile(KUrl::AddTrailingSlash), path);
 
-    const quint32 permissions = (S_IRUSR | S_IWUSR | S_IXUSR);
+    const mode_t permissions = (S_IRUSR | S_IWUSR | S_IXUSR);
     KIO::SimpleJob* job = KIO::chmod(list.first().url(), permissions);
     QVERIFY(job->exec());
 
